@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: v_cback.h,v 1.30 2005/08/13 23:12:54 mbarbon Exp $
+// RCS-ID:      $Id: v_cback.h,v 1.33 2005/11/01 22:18:03 mbarbon Exp $
 // Copyright:   (c) 2000-2004 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -129,69 +129,6 @@ inline wxPliVirtualCallback::wxPliVirtualCallback( const char* package )
     return false;                                                             \
   }
 
-#define DEC_V_CBACK_SIZET__VOID_const( METHOD ) \
-  size_t METHOD() const
-
-#define DEF_V_CBACK_SIZET__VOID_const( CLASS, BASE, METHOD ) \
-  size_t CLASS::METHOD() const                                                \
-  {                                                                           \
-    dTHX;                                                                     \
-    if( wxPliVirtualCallback_FindCallback( aTHX_ &m_callback, #METHOD ) )     \
-    {                                                                         \
-        SV* ret = wxPliVirtualCallback_CallCallback( aTHX_ &m_callback,       \
-                                                     G_SCALAR, NULL );        \
-        size_t val = SvUV( ret );                                             \
-        SvREFCNT_dec( ret );                                                  \
-        return val;                                                           \
-    } else                                                                    \
-        return BASE::METHOD();                                                \
-  }
-
-#define DEC_V_CBACK_BOOL__VOIDP_const( METHOD ) \
-  bool METHOD( void* ) const
-
-#define DEF_V_CBACK_BOOL__VOIDP_const( CLASS, BASE, METHOD ) \
-  bool CLASS::METHOD( void* param1 ) const                                    \
-  {                                                                           \
-    dTHX;                                                                     \
-    if( wxPliVirtualCallback_FindCallback( aTHX_ &m_callback, #METHOD ) )     \
-    {                                                                         \
-        SV* buf = newSViv( 0 );                                               \
-        SV* ret = wxPliVirtualCallback_CallCallback( aTHX_ &m_callback,       \
-                                                     G_SCALAR,                \
-                                                     "s", buf );              \
-        STRLEN len;                                                           \
-        char* val = SvPV( buf, len );                                         \
-        memcpy( param1, val, len );                                           \
-        bool retv = SvTRUE( ret );                                            \
-        SvREFCNT_dec( buf );                                                  \
-        SvREFCNT_dec( ret );                                                  \
-        return retv;                                                          \
-    } else                                                                    \
-        return BASE::METHOD( param1 );                                        \
-  }
-
-#define DEC_V_CBACK_BOOL__SIZET_CVOIDP( METHOD ) \
-  bool METHOD( size_t, const void* )
-
-#define DEF_V_CBACK_BOOL__SIZET_CVOIDP( CLASS, BASE, METHOD ) \
-  bool CLASS::METHOD( size_t param1, const void* param2 )                     \
-  {                                                                           \
-    dTHX;                                                                     \
-    if( wxPliVirtualCallback_FindCallback( aTHX_ &m_callback, #METHOD ) )     \
-    {                                                                         \
-        SV* n = newSVpvn( CHAR_P (const char*)param2, param1 );               \
-        SV* ret = wxPliVirtualCallback_CallCallback( aTHX_ &m_callback,       \
-                                                     G_SCALAR,                \
-                               "s", n );                                      \
-        bool val = SvTRUE( ret );                                             \
-        SvREFCNT_dec( ret );                                                  \
-        SvREFCNT_dec( n );                                                    \
-        return val;                                                           \
-    } else                                                                    \
-        return BASE::METHOD( param1, param2 );                                \
-  }
-
 #define DEC_V_CBACK_BOOL__WXDRAGRESULT( METHOD ) \
   bool METHOD( wxDragResult )
 
