@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     25/11/2000
-## RCS-ID:      $Id: Menu.pm,v 1.10 2004/10/19 20:28:12 mbarbon Exp $
-## Copyright:   (c) 2000-2003 Mattia Barbon
+## RCS-ID:      $Id: Menu.pm,v 1.11 2005/07/05 19:53:05 mbarbon Exp $
+## Copyright:   (c) 2000-2003, 2005 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -17,9 +17,9 @@ use strict;
 sub Append {
   my( $this ) = shift;
 
-  Wx::_match( @_, $Wx::_n_s_wmen, 3, 1 ) && ( $this->AppendSubMenu( @_ ), return );
-  Wx::_match( @_, $Wx::_n_s, 2, 1 )      && ( $this->AppendString( @_ ), return );
-  Wx::_match( @_, $Wx::_wmit, 1 )        && ( $this->AppendItem( @_ ), return );
+  Wx::_match( @_, $Wx::_n_s_wmen, 3, 1 ) && ( return $this->AppendSubMenu( @_ ) );
+  Wx::_match( @_, $Wx::_n_s, 2, 1 )      && ( return $this->AppendString( @_ ) );
+  Wx::_match( @_, $Wx::_wmit, 1 )        && ( return $this->AppendItem( @_ ) );
   Wx::_croak Wx::_ovl_error;
 }
 
